@@ -308,7 +308,7 @@ class TrapFailure(base.Processor):
     def process(self, baton):
         f = failure.Failure()
         trapped = f.trap(*self.error_types)
-        baton = self.get_resulting_baton(baton, self.output_path, trapped)
+        baton = self.get_resulting_baton(baton, self.output_path, f)
         return baton
 
 
@@ -911,8 +911,6 @@ class Logger(base.Processor):
         return baton
 
 
-#DEPENDENCY_CALLER_NO_ARGUMENTS = object()
-
 class DependencyCaller(base.Processor):
     """ Calls a method on a dependency.
 
