@@ -73,15 +73,15 @@ def run_piped():
 class VersionAction(argparse.Action):
     """ We provide our own argparse.Action in order to provide our own formatting. """
 
-    def _find_contrib_versions(self):
+    def _find_plugin_versions(self):
         from twisted.python import modules
 
         versions = dict()
 
-        contrib_module = modules.getModule('piped.contrib')
-        contrib_module.load()
+        plugin_module = modules.getModule('piped.plugins')
+        plugin_module.load()
 
-        for module in contrib_module.iterModules():
+        for module in plugin_module.iterModules():
             versions[module.name] = getattr(module.load(), 'version', 'unknown version')
 
         return versions
@@ -91,7 +91,7 @@ class VersionAction(argparse.Action):
         message.append('piped (the Piped process daemon) %s, %s' % (piped.version, twisted.version))
         message.append('')
         message.append('Contrib packages:')
-        for name, version in sorted(self._find_contrib_versions().items()):
+        for name, version in sorted(self._find_plugin_versions().items()):
             message.append('\t%s: %s' % (name, version))
         message.append('')
         message.append('Python version: %s' % sys.version.replace('\n', ''))
@@ -125,6 +125,9 @@ def _make_parser():
                        help=('Script file to use. If this argument is used, any unknown arguments passed to piped '
                              'will remain on sys.argv and can be consumed by the script.'), metavar='config_file.yaml')
 
+    parser.add_argument('-r', '--reactor', help='Which reactor to use, (see --help-reactors for a list of possibilities)')
+    parser.add_argument('--help-reactors', action='store_true', help='Display a list of possibly available reactor names.')
+
     return parser
 
 
@@ -149,6 +152,12 @@ def _create_configuration_for_twistd(args):
     twistd_config = twistd.ServerOptions()
     twistd_config.update(config)
 
+    if config['help_reactors']:
+        twistd_config.opt_help_reactors()
+
+    if config['reactor']:
+        twistd_config.opt_reactor(config['reactor'])
+
     return twistd_config
 
 
@@ -159,5 +168,10 @@ def _run_twistd_with_config(twistd_config):
         from piped import util
         failure._OriginalFailure = failure.Failure
         failure.Failure = util.NonCleaningFailure
+
+        # and enable debugging on deferreds, so we can properly inspect post-mortem
+        from twisted.internet import defer
+        defer.setDebugging(True)
+
     sys.argv[0] = 'twistd' # pretend to be twistd, so that piped.log doesn't decide to bootstrap the logging system
     twistd.runApp(twistd_config)
